Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1891)

Unified Diff: src/execution.cc

Issue 177683002: Mode clean-up pt 1: rename classic/non-strict mode to sloppy mode (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/elements-kind.cc ('k') | src/factory.cc » ('j') | src/globals.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/execution.cc
diff --git a/src/execution.cc b/src/execution.cc
index 690a4e3f4e6cd8570a0b052ee643b8fedb24aa69..6598ebe0f48bdf527923dad4e0bfbe70680461f2 100644
--- a/src/execution.cc
+++ b/src/execution.cc
@@ -163,9 +163,9 @@ Handle<Object> Execution::Call(Isolate* isolate,
}
Handle<JSFunction> func = Handle<JSFunction>::cast(callable);
// In non-strict mode, convert receiver.
if (convert_receiver && !receiver->IsJSReceiver() &&
- !func->shared()->native() && func->shared()->is_classic_mode()) {
+ !func->shared()->native() && func->shared()->is_sloppy_mode()) {
if (receiver->IsUndefined() || receiver->IsNull()) {
Object* global = func->context()->global_object()->global_receiver();
// Under some circumstances, 'global' can be the JSBuiltinsObject
@@ -163,9 +163,9 @@ Handle<Object> Execution::Call(Isolate* isolate,
}
Handle<JSFunction> func = Handle<JSFunction>::cast(callable);
- // In non-strict mode, convert receiver.
+ // In sloppy mode, convert receiver.
if (convert_receiver && !receiver->IsJSReceiver() &&
« no previous file with comments | « src/elements-kind.cc ('k') | src/factory.cc » ('j') | src/globals.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698